@@ -159,7 +159,11 @@ class OpenEuler():
         prev_value = None
         current_value = value
         # 循环替换直到无变化（处理嵌套宏）
+        index = 0
         while current_value != prev_value:
+            index+=1
+            if index>=10:
+                break
             prev_value = current_value
             for pattern, replacement in patterns:
                 try:
